from distutils.core import setup
setup(
  name='pezLogger',
  packages=['pezLogger'],
  version='1.1.1',
  license='MIT',
  description='Custom logger',
  author='Jason \'Perry\' Taylor',
  author_email='yesmynameisperry@gmail.com',
  url='https://github.com/YesmynameisPerry/pezLogger',
  keywords=['LOGGER', 'CUSTOM', 'PEZ'],
  install_requires=[],
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.8',
  ],
)